@@ -1,6 +1,3 @@
-"""
-
-"""
 import os
 import pathlib
 from urllib.parse import urlparse
@@ -12,11 +9,13 @@ def handle_file_uri(schema_path: pathlib.Path):
     def resolver(uri: str):
         parsed_uri = urlparse(uri)
 
-        if parsed_uri.path.startswith("/"):
-            file_path = pathlib.Path(uri).absolute()
+        if os.path.isdir(schema_path):
+            path_to_ref_schema = schema_path
 
-        path = schema_path.parent
-        file_path = pathlib.Path(path).joinpath(pathlib.Path(uri)).absolute()
+        if os.path.isfile(schema_path):
+            path_to_ref_schema = schema_path.parent
+
+        file_path = pathlib.Path(path_to_ref_schema).joinpath(pathlib.Path(uri)).absolute()
 
         return load_file(str(file_path))
 
