@@ -5,7 +5,8 @@ from pytest_mock import MockFixture
 import pytest
 import yaml
 
-from jsonschema_cli.args import create_parser, JsonschemaException
+from jsonschema_cli.args import create_parser
+from jsonschema_cli.exceptions import JsonschemaCliException
 import jsonschema
 
 
@@ -88,29 +89,31 @@ def test_failed_load_json_schema_yaml_instance(fail_validation_arguments):
     args.func(args)
 
 
-@pytest.mark.xfail(raises=JsonschemaException)
+@pytest.mark.xfail(raises=JsonschemaCliException)
 def test_load_empty_instance_fails(success_arguments):
     schema, instance = success_arguments
 
     args = create_parser().parse_args(["validate", json.dumps(schema), ""])
     args.func(args)
 
+
 def test_load_json_schema_file(mocker: MockFixture, success_arguments: tuple):
     schema, instance = success_arguments
 
-    mock_isfile = mocker.patch('os.path.isfile')
+    mock_isfile = mocker.patch("os.path.isfile")
     mock_isfile.side_effect = lambda x: x.name == "schema.json"
 
-    mock_load_file = mocker.patch('jsonschema_cli.args.load_file', mocker.MagicMock(return_value=schema))
+    mock_load_file = mocker.patch("jsonschema_cli.args.load_file", mocker.MagicMock(return_value=schema))
     args = create_parser().parse_args(["validate", "schema.json", json.dumps(instance)])
     args.func(args)
 
+
 def test_load_yaml_schema_file(mocker: MockFixture, success_arguments: tuple):
     schema, instance = success_arguments
 
-    mock_isfile = mocker.patch('os.path.isfile')
+    mock_isfile = mocker.patch("os.path.isfile")
     mock_isfile.side_effect = lambda x: x.name == "schema.yaml"
 
-    mock_load_file = mocker.patch('jsonschema_cli.args.load_file', mocker.MagicMock(return_value=schema))
+    mock_load_file = mocker.patch("jsonschema_cli.args.load_file", mocker.MagicMock(return_value=schema))
     args = create_parser().parse_args(["validate", "schema.yaml", yaml.dump(instance)])
     args.func(args)
